const {body, validationResult } = require('express-validator');

exports.signupValidator = [
    body('firstName').not().isEmpty().trim().withMessage("First name is required"),
    body('lastName').not().isEmpty().trim().withMessage("Last name is required"),
    body('email').isEmail().normalizeEmail().withMessage("Email is required"),
    body('password').isLength({min: 6}).withMessage("Password must be at least 6 characters long"),
]

exports.eventValidator = [
    body('eventTitle').isLength({min: 3, max: 50}).withMessage("Event title must be 3-50 characters long"),
    body('organiser').isLength({min: 3, max: 25}).withMessage("Organiser must be 3-25 characters long"),
    body('venueName').isLength({min: 3, max: 25}).withMessage("Venue name must be 3-25 characters long"),
    body('venueAddress').isLength({min: 3, max: 35}).withMessage("Venue address must be 3-35 characters long"),
    body('eventGenre').isLength({min: 3, max: 20}).withMessage("Event genre must be 3-20 characters long"),
    body('startDate').isLength({min: 5, max: 10}).withMessage("Event date must be 5-10 characters long"),
    body('endDate').isLength({min: 5, max: 10}).withMessage("Event date must be 5-10 characters long"),
    body('startTime').isLength({min: 5}).withMessage("Event date must be 5 characters long"),
    body('endTime').not().isEmpty().trim().withMessage("End time is required"),
    body('ticketPrice').not().isEmpty().trim().withMessage("Ticket price is required"),
    body('ticketQty').not().isEmpty().withMessage("Ticket quantity is required"),
    // body('eventImage').not().isEmpty().trim().withMessage("Image is required"),
    body('eventDescription').isLength({min: 6}).withMessage("Description is required"),
]

exports.signinValidator = [
    body('email').isEmail().normalizeEmail().withMessage("Email is required"),
    body('password').isLength({min: 6}).withMessage("Password must be at least 6 characters long"),
]

exports.validatorResult = (req, res, next) => {
    const result = validationResult(req);
    const hasErrors = !result.isEmpty();

    if (hasErrors) {
        const error = result.array()[0].msg

        console.log('Has errors:', hasErrors)
        console.log("result", result)

        return res.status(400).json({
            errorMessage: error
        })
        
    }
    next();
}

// Validate purchase details 
exports.purchaseValidator = [
    body('addressLine1').not().isEmpty().trim().withMessage("Address line 1 is required"),
    body('addressLine1').isLength({min: 3, max: 50}).withMessage("Address line 1 must be between 3 - 50 characters long"),
    body('city').not().isEmpty().trim().withMessage("City is required"),
    body('county').not().isEmpty().trim().withMessage("County is required"),
    body('postCode').not().isEmpty().trim().withMessage("Postcode is required"),
    body('cardholderName').isLength({min: 3, max: 50}).withMessage("Cardholder name must be 3 - 50 characters long"),
    body('cardNumber').isLength({min: 16, max: 16}).withMessage("Card number must be 16 numbers"),
    body('cardExpiryDate').isLength({min: 5, max: 5}).withMessage("Card expiry date must be valid"),
    body('cardCVC').isLength({min: 3, max: 3}).withMessage("CVC number must be 3 numbers"),
]  

