import User from "../models/userModel";
import bcrypt from "bcryptjs";
import jwt from 'jsonwebtoken';
import { jwtSecret, jwtExpire } from "../config/jwtKeys";

// export vs module exports (which works) - fix refactor later
exports.signupController = async (req, res) => {
  console.log("inside controller", req.body);

  // Destructuring sign up post request body into seperate variables for ref
  const { firstName, lastName, email, password } = req.body;

  try {

    const user = await User.findOne({ email });
    if (user) {
      return res.status(400).json({
        errorMessage: "Email already in use",
      });
    }

    // Creating new instance of user from model
    const newUser = new User();

    // Generating salt for password hash
    const passwordSalt = await bcrypt.genSalt(10);

    // Assigning database fields to req fields
    newUser.firstName = firstName;
    newUser.lastName = lastName;
    newUser.email = email;
    newUser.password = await bcrypt.hash(password, passwordSalt);

    // Saving user model to database
    await newUser.save();

    res.json({
      successMessage: "Successfully signed up",
    });
  } catch (err) {
    console.log("SignupController error:", err)
    res.status(500).json({
        errorMessage: "Server error"
    })
  }
};

exports.signinController = async (req, res) => {
  console.log("inside controller", req.body)
  const {email, password} = req.body

  try {

    //Checking if user email exists
    const user = await User.findOne({email})
    if (!user) {
      return res.status(400).json({
        errorMessage: "Invalid credentials"
      })
    }

    // Checking if user passwords match
    const userMatch = await bcrypt.compare(password, user.password)

    if (!userMatch) {
      return res.status(400).json({
        errorMessage: "Invalid credentials"
      })
    }
    
    // Constructing JWT payload 
    const payload = {
      user: {
        _id: user._id
      }
    }

    jwt.sign(payload, jwtSecret, {expiresIn: jwtExpire}, (err, token) => {
      if (err) {
        console.log("token authentication error", err)
      }
      const {_id, email, password} = user

      res.json({
        token,
        user: {_id, email}
      })

    })

  } catch (err) {
    console.log("signinController error:", err)
    res.status(500).json({
      errorMessage: 'Server error'
    })
  }
};

