import express from 'express'; 
import mongoose from 'mongoose';
import cors from 'cors'; 
import cookieParser from 'cookie-parser'
import eventRoutes from './routes/eventRoutes';
import authRoutes from './routes/authRoutes';
import purchaseRoutes from './routes/purchaseRoutes';

// Creating express object and declaring hosting server port
const app = express();
const PORT = 4000; 
var bodyParser = require('body-parser')

const db = require("./models")

// MongoDB connection 
db.mongoose.Promise = global.Promise; 
db.mongoose.connect('mongodb://localhost/TickcryptDB', {
    useNewUrlParser: true, 
    useUnifiedTopology: true
})
.then((result) => console.log('Connected to DB'))
.catch((err) => {
    // Close process after 
    console.log(err)
    process.exit();
});

// Body parser setup
app.use(express.urlencoded({extended: true}));
app.use(express.json());

// CORS setup 
app.use(cors());

// Allowing cookie parsing
app.use(cookieParser());

//Parse properly
app.use(bodyParser.urlencoded({ extended: false }))
app.use(bodyParser.json())
  
// Set EJS as templating engine 
app.set("view engine", "ejs");

// Declaring routes to the express server
eventRoutes(app)
authRoutes(app)
purchaseRoutes(app)

app.get('/', (req, res) => 
    res.send(`Tickcrypt app is running on ${PORT}`)

);

app.listen(PORT, () =>      
    console.log(`Your app server is running on port ${PORT}`)
);
